OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 信息不可用",
    "Load average: {cpu} (last minute)" : "负载平均值： {cpu} （上一分钟）",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: 总共：{memTotalBytes}/当前用量：{memUsageBytes}",
    "RAM info not available" : "RAM 信息不可用",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: 总共：{swapTotalBytes}/当前用量：{swapUsageBytes}",
    "SWAP info not available" : "SWAP 信息不可用",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "使用 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "使用 Ctrl-C 复制。",
    "System" : "系统",
    "Monitoring" : "监视器",
    "Monitoring app with useful server information" : "Monitoring app 监控有用的服务器信息",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的服务器信息，例如 CPU 负载、内存占用、硬盘占用、在线用户数等。",
    "Operating System:" : "操作系统：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "未知处理器",
    "Memory:" : "内存：",
    "Server time:" : "服务器时间：",
    "Uptime:" : "运行时长：",
    "Temperature" : "温度",
    "Load" : "负载",
    "Memory" : "内存",
    "Disk" : "磁盘",
    "Mount:" : "挂载：",
    "Filesystem:" : "文件系统：",
    "Size:" : "大小：",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "文件：",
    "Storages:" : "存储设备：",
    "Free Space:" : "剩余空间：",
    "Network" : "网络",
    "Hostname:" : "主机名：",
    "DNS:" : "DNS：",
    "Gateway:" : "网关：",
    "Status:" : "状态：",
    "Speed:" : "速度：",
    "Duplex:" : "复式：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活跃用户",
    "Total users:" : "总用户：",
    "24 hours:" : "24小时：",
    "1 hour:" : "1小时：",
    "5 mins:" : "5分钟：",
    "Shares" : "共享",
    "Users:" : "用户：",
    "Groups:" : "组别：",
    "Links:" : "链接：",
    "Emails:" : "邮箱：",
    "Federated sent:" : "联合云发送：",
    "Federated received:" : "联合云接收：",
    "Talk conversations:" : "通话应用对话：",
    "PHP" : "PHP",
    "Version:" : "版本：",
    "Memory limit:" : "内存限制：",
    "Max execution time:" : "最大执行时间：",
    "Upload max size:" : "最大上传大小：",
    "OPcache Revalidate Frequency:" : "OPcache重验证频率：",
    "Extensions:" : "扩展：",
    "Unable to list extensions" : "无法获取扩展列表",
    "Show phpinfo" : "显示phpinfo",
    "Database" : "数据库",
    "Type:" : "类型：",
    "External monitoring tool" : "外部监控工具",
    "Copy" : "复制",
    "To use an access token, please generate one then set it using the following command:" : "要使用一个访问令牌，请生成一个，然后使用以下命令设置它：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然后在查询上述 URL 时传递带有 “NC-Token” 头的令牌。"
},
"nplurals=1; plural=0;");
